======================================================
(ESNF-C) EVILEG Social Network Framework - Core Module
======================================================

`Social network EVILEG <https://evileg.com/>`_. Django app - core module

This application is core module of EVILEG

======
Donate
======

Please, support development of evileg-core module. We open part of EVILEG source code after stabilization in this module.

You can donate to us with following ways:

1. `PayPal.Me <https://www.paypal.me/legotckoi>`_
2. `Yandex.Money <https://money.yandex.ru/to/410011306906193>`_

=============
Documentation
=============

You can read documentation of this module on `EVILEG <https://evileg.com/docs/evileg_core/index.html>`_
